@@ -94,9 +94,4 @@ class ElectraForSequenceClassification(ElectraPreTrainedModel):
                 loss = loss_fct(logits.view(-1, self.config.num_labels), labels.view(-1))
             outputs = (loss,) + outputs
 
-        if self._index % 10000 == 0:
-            log.info((outputs, labels))
-        else:
-            self._index = self._index + 1
-
         return outputs  # (loss), logits,
